aboutsummaryrefslogtreecommitdiff
path: root/tools/translate_xmacro.h
diff options
context:
space:
mode:
Diffstat (limited to 'tools/translate_xmacro.h')
-rw-r--r--tools/translate_xmacro.h3
1 files changed, 2 insertions, 1 deletions
diff --git a/tools/translate_xmacro.h b/tools/translate_xmacro.h
index f68f317..958d8d9 100644
--- a/tools/translate_xmacro.h
+++ b/tools/translate_xmacro.h
@@ -16,11 +16,12 @@ TLS(WASM_I32_STORE8, storeb_p, i32_i32, empty)
TLS(WASM_I32_STORE16, storew_p, i32_i32, empty)
/*
* There are more checks to be performed in case of if, but we do them
* another way and only check for the i32 condition value here.
*/
TC (WASM_IF, if, i32, custom)
TC (WASM_BR, br, custom, custom)
+TC (WASM_BR_IF, br_if, i32, custom)
TC (WASM_CALL, call, custom, custom)
TC (WASM_LOCAL_GET, local_get, empty, custom)
TC (WASM_I32_CONST, const, empty, i32)
@@ -16,11 +16,12 @@ TLS(WASM_I32_STORE8, storeb_p, i32_i32, empty)
TLS(WASM_I32_STORE16, storew_p, i32_i32, empty)
/*
- * There are more checks to be performed in case of if, but we do them
+ * There are more checks to be performed in case of if and br_if, but we do them
* another way and only check for the i32 condition value here.
*/